@@ -1,4 +1,5 @@
 use crate::serialize::SizeBytes;
+use std::fmt;
 
 /// An error suggesting something went wrong during data (de)serialization.
 /// It can occur due to invald data, an IO error or an error in the
@@ -15,19 +16,33 @@ pub enum BinverseError {
     /// for the SizeBytes limitation.
     SizeExceeded {
         /// The SizeBytes limit set for the data structure.
-        limit: SizeBytes, 
+        limit: SizeBytes,
         /// The number of elements found in the data structure.
         found: usize
     },
-    /// A generic invalid data error 
+    /// A generic invalid data error
     InvalidData
 }
 /// A type alias for a Result with a BinverseError as the error type.
 pub type BinverseResult<T> = Result<T, BinverseError>;
 
+impl fmt::Display for BinverseError {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            Self::IO(err) => write!(f, "Binverse IO Error: {}", err),
+            Self::VarIntOverflow => write!(f, "VarInt overflow occured"),
+            Self::InvalidUTF8 => write!(f, "Invalid UTF8 data encountered"),
+            Self::SizeExceeded { limit, found } => write!(f, "Data structure size was exceeded, maximum allowed length was {} ({:?}) but found {}", limit.maximum(), limit, found),
+            Self::InvalidData => write!(f, "Data was invalid")
+        }
+    }
+}
+
 impl From<std::io::Error> for BinverseError {
     /// Wraps an IO error in the IO variant of BinverseError.
     fn from(e: std::io::Error) -> BinverseError {
         BinverseError::IO(e)
     }
-}
\ No newline at end of file
+}
+
+impl std::error::Error for BinverseError { }
\ No newline at end of file
